@@ -1,6 +1,7 @@
-__all__ = ['dcmreaddata', 'datareader', 'datawriter']
+__all__ = ['dcmreaddata', 'datareader', 'datawriter', 'rawN']
 # from pycut import Model, ImageGraphCut
 # from seed_editor_qt import QTSeedEditor
 from dcmreaddata import DicomReader
 from datawriter import DataWriter
 from datareader import DataReader
+
